import { useEffect, useState } from 'react';
import useSDKFactory from './useSDKFactory';
import { UseCase, RRListenable, SRListenable, } from '@inkerlabs/sdk';
import useAccount from '../common/useAccount';
export default function useNFTsFactory(useCase) {
    return function useNFTs() {
        var sdk = useSDKFactory()();
        var _a = useState(undefined), tokens = _a[0], setTokens = _a[1];
        var _b = useState(undefined), nfts = _b[0], setNfts = _b[1];
        var _c = useState(undefined), error = _c[0], setError = _c[1];
        useAccount();
        var id;
        var cb = function (err, tokens, nfts) {
            setTokens(tokens);
            setError(err);
            setNfts(nfts);
        };
        var unlisten = function () {
            switch (useCase) {
                case UseCase.RR:
                    var rrSDK = sdk;
                    if (id) {
                        rrSDK.unlisten(id, RRListenable.REVEALABLE);
                    }
                    break;
                case UseCase.SR:
                    var srSDK = sdk;
                    if (id) {
                        srSDK.unlisten(id, SRListenable.NFTS);
                    }
                    break;
                default:
                    throw new Error("Unsupported use case ".concat(useCase));
            }
        };
        useEffect(function () {
            unlisten();
            switch (useCase) {
                case UseCase.RR:
                    var rrSDK = sdk;
                    id = rrSDK.listen(RRListenable.REVEALABLE, cb);
                    break;
                case UseCase.SR:
                    var srSDK = sdk;
                    id = srSDK.listen(SRListenable.NFTS, cb);
                    break;
                default:
                    throw new Error("Unsupported use case ".concat(useCase));
            }
        }, []);
        // Emulate componentWillUnmount
        useEffect(function () {
            return function () {
                unlisten();
            };
        }, []);
        return { tokens: tokens, nfts: nfts, error: error };
    };
}
